@@ -27,6 +27,7 @@
 
 #include "libmuonprivate_export.h"
 
+class Transaction;
 class AbstractResource;
 
 class MUONPRIVATE_EXPORT ApplicationAddonsModel : public QAbstractListModel
@@ -44,6 +45,7 @@ class MUONPRIVATE_EXPORT ApplicationAddonsModel : public QAbstractListModel
         
         virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
         virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
+        virtual QHash<int, QByteArray> roleNames() const;
         bool isEmpty() const;
 
     public slots:
@@ -56,6 +58,9 @@ class MUONPRIVATE_EXPORT ApplicationAddonsModel : public QAbstractListModel
         void applicationChanged();
 
     private:
+        void transactionOver(Transaction* t);
+        void resetState();
+
         AbstractResource* m_app;
         QList<PackageState> m_initial;
         AddonList m_state;
