@@ -19,38 +19,38 @@
  ***************************************************************************/
 
 #include "Application.h"
-#include "resources/PackageState.h"
-#include "ApplicationBackend.h"
-#include <MuonDataSources.h>
 
 // Qt includes
-#include <QtCore/QFile>
-#include <QtCore/QVector>
-#include <QtCore/QStringList>
+#include <QFile>
+#include <QJsonDocument>
+#include <QStandardPaths>
+#include <QStringList>
 #include <QThread>
+#include <QVector>
 
 // KDE includes
 #include <KIconLoader>
-#include <KLocale>
 #include <KService>
 #include <KServiceGroup>
-#include <KDebug>
 #include <KToolInvocation>
+#include <KLocalizedString>
 #include <KIO/Job>
-#include <KIO/NetAccess>
-#include <KStandardDirs>
 #include <KConfigGroup>
+#include <KFormat>
 
 // QApt includes
-#include <LibQApt/Backend>
-#include <LibQApt/Config>
-#include <LibQApt/Changelog>
+#include <QApt/Backend>
+#include <QApt/Config>
+#include <QApt/Changelog>
 
-//QJSON includes
-#include <qjson/parser.h>
+#include <MuonDataSources.h>
+
+#include "ApplicationBackend.h"
+#include "resources/PackageState.h"
 
 Application::Application(const QString& fileName, QApt::Backend* backend)
         : AbstractResource(0)
+        , m_data(new KConfig(fileName, KConfig::SimpleConfig))
         , m_backend(backend)
         , m_package(0)
         , m_isValid(true)
@@ -60,7 +60,6 @@ Application::Application(const QString& fileName, QApt::Backend* backend)
 {
     static QByteArray currentDesktop = qgetenv("XDG_CURRENT_DESKTOP");
 
-    m_data = desktopContents(fileName);
     m_isTechnical = getField("NoDisplay").toLower() == "true"
                     || !hasField("Exec")
                     || getField("NotShowIn", QByteArray()).contains(currentDesktop)
@@ -213,8 +212,10 @@ QVector<QPair<QString, QString> > Application::locateApplication(const QString &
     for (KServiceGroup::List::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it) {
         const KSycocaEntry::Ptr p = (*it);
 
+        // Static cast to specific classes according to isType().
         if (p->isType(KST_KService)) {
-            const KService::Ptr service = KService::Ptr::staticCast(p);
+            const KService::Ptr service =
+                    KService::Ptr(static_cast<KService *>(p.data()));
 
             if (service->noDisplay()) {
                 continue;
@@ -228,7 +229,8 @@ QVector<QPair<QString, QString> > Application::locateApplication(const QString &
                 return ret;
             }
         } else if (p->isType(KST_KServiceGroup)) {
-            const KServiceGroup::Ptr serviceGroup = KServiceGroup::Ptr::staticCast(p);
+            const KServiceGroup::Ptr serviceGroup =
+                    KServiceGroup::Ptr(static_cast<KServiceGroup *>(p.data()));
 
             if (serviceGroup->noDisplay() || serviceGroup->childCount() == 0) {
                 continue;
@@ -254,12 +256,12 @@ QVector<QPair<QString, QString> > Application::locateApplication(const QString &
 
 QStringList Application::categories()
 {
-    QStringList categories = QString(getField("Categories")).split(';', QString::SkipEmptyParts);
+    QStringList categories = QString(getField("Categories")).split(',', QString::SkipEmptyParts);
 
     if (categories.isEmpty()) {
         // extras.ubuntu.com packages can have this field
         if (m_isExtrasApp)
-            categories = package()->controlField(QLatin1String("Category")).split(';');
+            categories += package()->controlField(QLatin1String("Category"));
     }
     return categories;
 }
@@ -268,7 +270,7 @@ QUrl Application::thumbnailUrl()
 {
     QUrl url(package()->controlField(QLatin1String("Thumbnail-Url")));
     if(m_sourceHasScreenshot) {
-        url = KUrl(MuonDataSources::screenshotsSource(), "thumbnail/"+packageName());
+        url = QUrl(MuonDataSources::screenshotsSource().toString() + "/thumbnail/" + packageName());
     }
     return url;
 }
@@ -277,7 +279,7 @@ QUrl Application::screenshotUrl()
 {
     QUrl url(package()->controlField(QLatin1String("Screenshot-Url")));
     if(m_sourceHasScreenshot) {
-        url = KUrl(MuonDataSources::screenshotsSource(), "screenshot/"+packageName());
+        url = QUrl(MuonDataSources::screenshotsSource().toString() + "/screenshot/" + packageName());
     }
     return url;
 }
@@ -420,13 +422,14 @@ QString Application::installedVersion() const
 
 QString Application::sizeDescription()
 {
+    KFormat f;
     if (!isInstalled()) {
         return i18nc("@info app size", "%1 to download, %2 on disk",
-                              KGlobal::locale()->formatByteSize(package()->downloadSize()),
-                              KGlobal::locale()->formatByteSize(package()->availableInstalledSize()));
+                              f.formatByteSize(package()->downloadSize()),
+                              f.formatByteSize(package()->availableInstalledSize()));
     } else {
         return i18nc("@info app size", "%1 on disk",
-                              KGlobal::locale()->formatByteSize(package()->currentInstalledSize()));
+                              f.formatByteSize(package()->currentInstalledSize()));
     }
 }
 
@@ -435,11 +438,6 @@ int Application::downloadSize()
     return m_package->downloadSize();
 }
 
-KSharedConfigPtr Application::desktopContents(const QString& filename)
-{
-    return KSharedConfig::openConfig(filename, KConfig::SimpleConfig);
-}
-
 void Application::clearPackage()
 {
     m_package = 0;
@@ -472,7 +470,7 @@ void Application::invokeApplication() const
 {
     QVector< KService::Ptr > execs = findExecutables();
     Q_ASSERT(!execs.isEmpty());
-    KToolInvocation::startServiceByDesktopPath(execs.first()->desktopEntryPath());
+    KToolInvocation::startServiceByDesktopName(execs.first()->desktopEntryName());
 }
 
 bool Application::canExecute() const
@@ -504,8 +502,8 @@ void Application::fetchScreenshots()
     if(!m_sourceHasScreenshot)
         return;
     
-    QString dest = KStandardDirs::locate("tmp", "screenshots."+m_packageName);
-    const KUrl packageUrl(MuonDataSources::screenshotsSource(), "/json/package/"+m_packageName);
+    QString dest = QStandardPaths::locate(QStandardPaths::TempLocation, "screenshots."+m_packageName);
+    const QUrl packageUrl(MuonDataSources::screenshotsSource().toString() + "/json/package/"+m_packageName);
     KIO::StoredTransferJob* job = KIO::storedGet(packageUrl, KIO::NoReload, KIO::HideProgressInfo);
     connect(job, SIGNAL(finished(KJob*)), SLOT(downloadingScreenshotsFinished(KJob*)));
 }
@@ -515,10 +513,10 @@ void Application::downloadingScreenshotsFinished(KJob* j)
     KIO::StoredTransferJob* job = qobject_cast< KIO::StoredTransferJob* >(j);
     bool done = false;
     if(job) {
-        QJson::Parser p;
-        bool ok;
-        QVariantMap values = p.parse(job->data(), &ok).toMap();
-        if(ok) {
+        QJsonParseError error;
+        QJsonDocument doc = QJsonDocument::fromJson(job->data(), &error);
+        if(error.error != QJsonParseError::NoError) {
+            QVariantMap values = doc.toVariant().toMap();
             QVariantList screenshots = values["screenshots"].toList();
             
             QList<QUrl> thumbnailUrls, screenshotUrls;
@@ -551,8 +549,8 @@ QStringList Application::executables() const
 {
     QStringList ret;
     QVector<KService::Ptr> exes = findExecutables();
-    foreach(KService::Ptr exe, exes) {
-        ret += exe->desktopEntryPath();
+    for(KService::Ptr exe : exes) {
+        ret += exe->exec();
     }
     return ret;
 }
@@ -612,7 +610,8 @@ QString Application::buildDescription(const QByteArray& data, const QString& sou
         description += i18nc("@info:label Refers to a software version, Ex: Version 1.2.1:",
                              "Version %1:", entry.version());
 
-        QString issueDate = KGlobal::locale()->formatDateTime(entry.issueDateTime(), KLocale::ShortDate);
+        KFormat f;
+        QString issueDate = entry.issueDateTime().toString(Qt::DefaultLocaleShortDate);
         description += QLatin1String("<p>") +
                        i18nc("@info:label", "This update was issued on %1", issueDate) +
                        QLatin1String("</p>");
