@@ -27,24 +27,22 @@
 #include <QtCore/QStringList>
 #include <QtCore/QUuid>
 #include <QTimer>
+#include <QSignalMapper>
+#include <QJsonDocument>
+#include <QAction>
 
 // KDE includes
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KProcess>
 #include <KProtocolManager>
-#include <KStandardDirs>
 #include <KIO/Job>
-#include <KDebug>
-#include <KAboutData>
-#include <KAction>
 #include <KActionCollection>
 
-// LibQApt/DebconfKDE includes
-#include <LibQApt/Backend>
-#include <LibQApt/Transaction>
+// QApt/DebconfKDE includes
+#include <QApt/Backend>
+#include <QApt/Transaction>
 #include <DebconfGui.h>
-#include <qjson/parser.h>
 
 //libmuonapt includes
 #include "MuonStrings.h"
@@ -52,31 +50,34 @@
 #include "QAptActions.h"
 
 // Own includes
+#include "AptSourcesBackend.h"
 #include "Application.h"
 #include "ReviewsBackend.h"
 #include "Transaction/Transaction.h"
 #include "Transaction/TransactionModel.h"
 #include "ApplicationUpdates.h"
 #include "MuonMainWindow.h"
+#include <resources/SourcesModel.h>
 #include <MuonDataSources.h>
 
-static const KCatalogLoader loader("app-install-data");
+// static const KCatalogLoader loader("app-install-data"); //FIXME port
 
-K_PLUGIN_FACTORY(MuonAppsBackendFactory, registerPlugin<ApplicationBackend>(); )
-K_EXPORT_PLUGIN(MuonAppsBackendFactory(KAboutData("muon-appsbackend","muon-appsbackend",ki18n("Applications Backend"),"0.1",ki18n("Applications in your system"), KAboutData::License_GPL)))
+MUON_BACKEND_PLUGIN(ApplicationBackend);
 
-ApplicationBackend::ApplicationBackend(QObject* parent, const QVariantList& )
+ApplicationBackend::ApplicationBackend(QObject* parent)
     : AbstractResourcesBackend(parent)
     , m_backend(new QApt::Backend(this))
     , m_reviewsBackend(new ReviewsBackend(this))
     , m_isFetching(true)
+    , m_wantedTransaction(nullptr)
     , m_currentTransaction(nullptr)
     , m_backendUpdater(new ApplicationUpdates(this))
     , m_aptify(nullptr)
     , m_aptBackendInitialized(false)
 {
-    KGlobal::dirs()->addResourceDir("appicon", "/usr/share/app-install/icons/");
-    
+//   TODO: Port
+//     KGlobal::dirs()->addResourceDir("appicon", "/usr/share/app-install/icons/");
+
     m_watcher = new QFutureWatcher<QVector<Application*> >(this);
     connect(m_watcher, SIGNAL(finished()), this, SLOT(setApplications()));
     connect(m_reviewsBackend, SIGNAL(ratingsReady()), SIGNAL(allDataChanged()));
@@ -141,8 +142,8 @@ void ApplicationBackend::setApplications()
     m_appList = m_watcher->future().result();
     for (Application* app : m_appList)
         app->setParent(this);
-    
-    KIO::StoredTransferJob* job = KIO::storedGet(KUrl(MuonDataSources::screenshotsSource(), "/json/packages"),KIO::NoReload, KIO::DefaultFlags|KIO::HideProgressInfo);
+
+    KIO::StoredTransferJob* job = KIO::storedGet(QUrl(MuonDataSources::screenshotsSource().toString() + "/json/packages"),KIO::NoReload, KIO::DefaultFlags|KIO::HideProgressInfo);
     connect(job, SIGNAL(finished(KJob*)), SLOT(initAvailablePackages(KJob*)));
 
     if (m_aptify)
@@ -275,6 +276,12 @@ void ApplicationBackend::errorOccurred(QApt::ErrorCode error)
     if (m_transQueue.isEmpty()) // Shouldn't happen
         return;
 
+    if( error == QApt::AuthError){
+        m_currentTransaction->cancel();
+        m_transQueue.remove(m_currentTransaction);
+        m_currentTransaction->deleteLater();
+        m_currentTransaction = nullptr;
+    }
     QAptActions::self()->displayTransactionError(error, m_transQueue.value(m_currentTransaction));
 }
 
@@ -333,11 +340,15 @@ void ApplicationBackend::markTransaction(Transaction *transaction)
 
 void ApplicationBackend::markLangpacks(Transaction *transaction)
 {
-    QString prog = KStandardDirs::findExe("check-language-support");
-    if (prog.isEmpty())
-        return;
+    QString prog = QStandardPaths::findExecutable("check-language-support");
+    if (prog.isEmpty()){
+        prog =  QStandardPaths::locate(QStandardPaths::GenericDataLocation, "muon/scripts/check-language-support");
+        if ( prog.isEmpty()){
+            return;
+        }
+    }
 
-    QString language = KGlobal::locale()->language();
+    QString language = QLocale().name();
     QString pkgName = transaction->resource()->packageName();
 
     QStringList args;
@@ -352,11 +363,10 @@ void ApplicationBackend::markLangpacks(Transaction *transaction)
     QString res = proc.readAllStandardOutput();
     res.remove(QString());
 
-    QApt::Package *langPack = nullptr;
     m_backend->setCompressEvents(true);
     foreach(const QString &pkg, res.split(' '))
     {
-        langPack = m_backend->package(pkg.trimmed());
+        QApt::Package *langPack = m_backend->package(pkg.trimmed());
 
         if (langPack)
             langPack->setInstall();
@@ -366,6 +376,9 @@ void ApplicationBackend::markLangpacks(Transaction *transaction)
 
 void ApplicationBackend::addTransaction(Transaction *transaction)
 {
+    if(!transaction){
+      return;
+    }
     QApt::CacheState oldCacheState = m_backend->currentCacheState();
     m_backend->saveCacheState();
 
@@ -374,7 +387,6 @@ void ApplicationBackend::addTransaction(Transaction *transaction)
     // Find changes due to markings
     QApt::PackageList excluded;
     excluded.append(qobject_cast<Application*>(transaction->resource())->package());
-
     // Exclude addons being marked
     for (const QString &pkgStr : transaction->addons().addonsToInstall()) {
         QApt::Package *addon = m_backend->package(pkgStr);
@@ -458,13 +470,18 @@ void ApplicationBackend::installApplication(AbstractResource* res, AddonList add
 {
     Application* app = qobject_cast<Application*>(res);
     Transaction::Role role = app->package()->isInstalled() ? Transaction::ChangeAddonsRole : Transaction::InstallRole;
-
-    addTransaction(new Transaction(this, res, role, addons));
+    QStringList pkgName;
+    pkgName << app->packageName();
+    m_wantedTransaction = new Transaction(this, res, role, addons);
+    aptListBugs(pkgName);
 }
 
 void ApplicationBackend::installApplication(AbstractResource* app)
 {
-    addTransaction(new Transaction(this, app, Transaction::InstallRole));
+    QStringList pkgName;
+    pkgName << app->packageName();
+    m_wantedTransaction = new Transaction(this, app, Transaction::InstallRole);
+    aptListBugs(pkgName);
 }
 
 void ApplicationBackend::removeApplication(AbstractResource* app)
@@ -525,8 +542,8 @@ void ApplicationBackend::integrateMainWindow(MuonMainWindow* w)
         connect(this, SIGNAL(aptBackendInitialized(QApt::Backend*)), apt, SLOT(setBackend(QApt::Backend*)));
     if (apt->reloadWhenSourcesEditorFinished())
         connect(apt, SIGNAL(sourcesEditorClosed(bool)), SLOT(reload()));
-    KAction* updateAction = w->actionCollection()->addAction("update");
-    updateAction->setIcon(KIcon("system-software-update"));
+    QAction* updateAction = w->actionCollection()->addAction("update");
+    updateAction->setIcon(QIcon::fromTheme("system-software-update"));
     updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
     updateAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
     updateAction->setEnabled(w->isConnected());
@@ -564,6 +581,8 @@ void ApplicationBackend::initBackend()
             this, SLOT(aptTransactionsChanged(QString)));
     connect(m_backend, SIGNAL(xapianUpdateFinished()),
             this, SIGNAL(searchInvalidated()));
+
+    SourcesModel::global()->addSourcesBackend(new AptSourcesBackend(this));
 }
 
 void ApplicationBackend::setupTransaction(QApt::Transaction *trans)
@@ -594,13 +613,13 @@ void ApplicationBackend::initAvailablePackages(KJob* j)
 {
     KIO::StoredTransferJob* job = qobject_cast<KIO::StoredTransferJob*>(j);
     Q_ASSERT(job);
-    
-    bool ok=false;
-    QJson::Parser p;
-    QVariantList data = p.parse(job->data(), &ok).toMap().value("packages").toList();
-    if(!ok)
-        kWarning() << "errors!" << p.errorString();
+
+    QJsonParseError error;
+    QJsonDocument doc = QJsonDocument::fromJson(job->data(), &error);
+    if(error.error != QJsonParseError::NoError)
+        qWarning() << "errors!" << error.errorString();
     else {
+        QVariantList data = doc.toVariant().toMap().value("packages").toList();
         Q_ASSERT(!m_appList.isEmpty());
         QSet<QString> packages;
         foreach(const QVariant& v, data) {
@@ -651,3 +670,45 @@ void ApplicationBackend::setFetching(bool f)
         }
     }
 }
+
+void ApplicationBackend::listBugsFinished()
+{
+    bool ok = true;
+    KProcess *mProcess = qobject_cast<KProcess*>(QObject::sender());
+    if (!mProcess) {
+        return;
+    }
+    QString output = QString::fromUtf8(mProcess->readAllStandardOutput());
+    mProcess->deleteLater();
+    if (!output.isEmpty()) {
+        QMessageBox::StandardButton reply;
+        reply = QMessageBox::question(mainWindow(), QString("Bugs found"), output ,QMessageBox::Yes|QMessageBox::No);
+        if (reply == QMessageBox::No) {
+            ok = false;
+        }
+    }
+    if (ok) {
+        if (m_wantedTransaction){
+            addTransaction(m_wantedTransaction);
+            m_wantedTransaction = nullptr;
+        }
+        emit transactionOk();
+    }
+}
+
+void ApplicationBackend::aptListBugs(QStringList packageName)
+{
+    QStringList arguments;
+    QString program = QStandardPaths::findExecutable(QString("apt-listbugs"));
+    if (program.isEmpty()) {
+        emit transactionOk();
+        return;
+    }
+    KProcess *proc = new KProcess;
+    proc->setOutputChannelMode(KProcess::OnlyStdoutChannel);
+    proc->setShellCommand(program.append(QString(" list ")).append(packageName.join(" , ")));
+    connect(proc, SIGNAL(finished(int)), this, SLOT(listBugsFinished()));
+    proc->start();
+}
+
+#include "ApplicationBackend.moc"
