@@ -28,10 +28,9 @@
 #include <QtCore/QStringList>
 #include <QtCore/QVector>
 
-#include <LibQApt/Package>
-#include <LibQApt/Backend>
+#include <QApt/Package>
+#include <QApt/Backend>
 
-#include <libmuonprivate_export.h>
 #include "resources/AbstractResourcesBackend.h"
 
 namespace QApt {
@@ -49,13 +48,12 @@ class Transaction;
 class QAptActions;
 class KJob;
 
-class MUONPRIVATE_EXPORT ApplicationBackend : public AbstractResourcesBackend
+class ApplicationBackend : public AbstractResourcesBackend
 {
     Q_OBJECT
-    Q_INTERFACES(AbstractResourcesBackend)
     Q_PROPERTY(QObject* backend READ backend)
 public:
-    explicit ApplicationBackend(QObject *parent, const QVariantList& args);
+    explicit ApplicationBackend(QObject *parent = 0);
     ~ApplicationBackend();
 
     bool isValid() const;
@@ -69,7 +67,6 @@ public:
     bool isFetching() const;
     void markTransaction(Transaction *transaction);
     void markLangpacks(Transaction *transaction);
-    void addTransaction(Transaction *transaction);
     
     QVector< AbstractResource* > allResources() const;
     QList<AbstractResource*> searchPackageName(const QString& searchText);
@@ -83,7 +80,8 @@ public:
     void integrateMainWindow(MuonMainWindow* w);
     QWidget* mainWindow() const;
     virtual QList<AbstractResource*> upgradeablePackages() const;
-
+    void aptListBugs(QStringList packageName);
+    
 private:
     void setFetching(bool f);
     
@@ -96,16 +94,16 @@ private:
 
     // Transactions
     QHash<Transaction *, QApt::Transaction *> m_transQueue;
+    Transaction *m_wantedTransaction;
     Transaction *m_currentTransaction;
 
     DebconfKde::DebconfGui *m_debconfGui;
     ApplicationUpdates* m_backendUpdater;
     MuonMainWindow *m_aptify;
     bool m_aptBackendInitialized;
-
 public Q_SLOTS:
     void reload();
-
+    void addTransaction(Transaction *transaction);
     //helper functions
     void initAvailablePackages(KJob*);
 
@@ -120,9 +118,11 @@ private Q_SLOTS:
     void sourcesEditorClosed();
     void checkForUpdates();
     void updateFinished(QApt::ExitStatus);
+    void listBugsFinished();
 
 Q_SIGNALS:
-	void startingFirstTransaction();
+    void transactionOk();
+    void startingFirstTransaction();
     void sourcesEditorFinished();
     void aptBackendInitialized(QApt::Backend* backend);
 };
