@@ -23,89 +23,92 @@
 #include <QtCore/QFile>
 #include <QtCore/QTimer>
 #include <QtCore/QDebug>
+#include <QtCore/QStandardPaths>
+#include <QtCore/QProcess>
+#include <QtGui/QIcon>
 
 // KDE includes
-#include <KAboutData>
 #include <KDirWatch>
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KProcess>
-#include <KStandardDirs>
 #include <KNotification>
-#include <KIcon>
 #include <KIconLoader>
 
-// Own includes
-
-K_PLUGIN_FACTORY(ApplicationNotifierFactory,
-                 registerPlugin<ApplicationNotifier>();
-                )
-K_EXPORT_PLUGIN(ApplicationNotifierFactory("muon-application-notifier"))
-
-ApplicationNotifier::ApplicationNotifier(QObject* parent, const QVariantList &)
-  : AbstractKDEDModule("Application", "muondiscover", parent), 
-    m_checkerProcess(0), m_updateCheckerProcess(0), m_checkingForUpdates(false)
-{
-    KAboutData aboutData("muonapplicationnotifier", "muonapplicationnotifier",
-                         ki18n("Muon Notification Daemon"),
-                         "2.0", ki18n("A Notification Daemon for Muon"),
-                         KAboutData::License_GPL,
-                         ki18n("(C) 2013 Lukas Appelhans, (C) 2009-2012 Jonathan Thomas, (C) 2009 Harald Sitter"),
-                         KLocalizedString(), "http://kubuntu.org");
-    
-    QTimer::singleShot(2 * 60 * 1000, this, SLOT(init()));
-}
-
-ApplicationNotifier::~ApplicationNotifier()
-{
-    delete m_checkerProcess;
-    delete m_updateCheckerProcess;
-}
-
-void ApplicationNotifier::init()
+ApplicationNotifier::ApplicationNotifier(QObject* parent)
+  : BackendNotifierModule(parent)
+  , m_checkerProcess(Q_NULLPTR)
+  , m_updateCheckerProcess(Q_NULLPTR)
+  , m_checkingForUpdates(false)
+  , m_securityUpdates(0)
+  , m_normalUpdates(0)
 {
     KDirWatch *stampDirWatch = new KDirWatch(this);
     stampDirWatch->addFile("/var/lib/update-notifier/dpkg-run-stamp");
-    connect(stampDirWatch, SIGNAL(dirty(QString)),
-             this, SLOT(distUpgradeEvent()));
-    
-    distUpgradeEvent();
+    connect(stampDirWatch, &KDirWatch::dirty, this, &ApplicationNotifier::distUpgradeEvent);
 
     stampDirWatch = new KDirWatch(this);
     stampDirWatch->addDir("/var/lib/apt/lists/");
     stampDirWatch->addDir("/var/lib/apt/lists/partial/");
     stampDirWatch->addFile("/var/lib/update-notifier/updates-available");
     stampDirWatch->addFile("/var/lib/update-notifier/dpkg-run-stamp");
-    connect(stampDirWatch, SIGNAL(dirty(QString)),
-            this, SLOT(recheckSystemUpdateNeeded()));
+    connect(stampDirWatch, &KDirWatch::dirty, this, &ApplicationNotifier::recheckSystemUpdateNeeded);
+    
+#warning initial check is triggered by the notifier backends on different timeouts, perhaps the notifier should handle this globally rather than the backends independently
+    QTimer *delayedInitialization = new QTimer(this);
+    delayedInitialization->setInterval(2 * 60 * 1000); //check in 2 minutes
+    connect(delayedInitialization, &QTimer::timeout, this, &ApplicationNotifier::recheckSystemUpdateNeeded);
+}
 
+ApplicationNotifier::~ApplicationNotifier()
+{
+}
+
+void ApplicationNotifier::init()
+{
     recheckSystemUpdateNeeded();
+    distUpgradeEvent();
 }
 
 void ApplicationNotifier::distUpgradeEvent()
 {
-    QString checkerFile = KStandardDirs::locate("data", "muonapplicationnotifier/releasechecker");
-    qDebug() << "Run releasechecker: " << checkerFile;
-    m_checkerProcess = new KProcess(this);
+    QString checkerFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "muonapplicationnotifier/releasechecker");
+    if (checkerFile.isEmpty()) {
+        qWarning() << "Couldn't find the releasechecker" << checkerFile << QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+        return;
+    }
+    m_checkerProcess = new QProcess(this);
     connect(m_checkerProcess, SIGNAL(finished(int)),
             this, SLOT(checkUpgradeFinished(int)));
-    m_checkerProcess->setProgram(QStringList() << "/usr/bin/python3" << checkerFile);
-    m_checkerProcess->start();
+    m_checkerProcess->start("/usr/bin/python3", QStringList() << checkerFile);
 }
 
 void ApplicationNotifier::checkUpgradeFinished(int exitStatus)
 {
-    qWarning() << "checked for upgrades and return with " << exitStatus;
     if (exitStatus == 0) {
-        KNotification::event("DistUpgrade", i18n("System update available!"), i18nc("Notification when a new version of Kubuntu is available",
-                                 "A new version of Kubuntu is available"), KIcon("svn-update").pixmap(KIconLoader::SizeMedium), nullptr, KNotification::CloseOnTimeout, KComponentData("muonapplicationnotifier"));
-        setSystemUpToDate(false, AbstractKDEDModule::NormalUpdate, AbstractKDEDModule::DontShowNotification);
+        KNotification *n = KNotification::event("DistUpgrade",
+                                                i18n("System update available!"),
+                                                i18nc("Notification when a new version of Kubuntu is available",
+                                                      "A new version of Kubuntu is available"),
+                                                QIcon::fromTheme("svn-update").pixmap(KIconLoader::SizeMedium),
+                                                nullptr,
+                                                KNotification::CloseOnTimeout,
+                                                "muonapplicationnotifier");
+        n->setActions(QStringList() << i18n("Upgrade"));
+        connect(n, &KNotification::action1Activated, this, &ApplicationNotifier::upgradeActivated);
     }
 
     m_checkerProcess->deleteLater();
     m_checkerProcess = nullptr;
 }
 
+void ApplicationNotifier::upgradeActivated()
+{
+    QString kdesudo = QStandardPaths::findExecutable("kdesudo");
+    QString upgrader = QStringLiteral("do-release-upgrade -m desktop -f DistUpgradeViewKDE");
+    
+    QProcess::startDetached(kdesudo, QStringList() << upgrader);
+}
+
 void ApplicationNotifier::recheckSystemUpdateNeeded()
 {
     if (m_checkingForUpdates)
@@ -119,8 +122,9 @@ void ApplicationNotifier::recheckSystemUpdateNeeded()
     
 void ApplicationNotifier::parseUpdateInfo()
 {
-    int securityUpdates = 0;
-    int updates = 0;
+#warning why does this parse stdout and not use qapt, wtf...
+    m_securityUpdates = 0;
+    m_normalUpdates = 0;
     // Weirdly enough, apt-check gives output on stderr
     QByteArray line = m_updateCheckerProcess->readAllStandardError();
     m_updateCheckerProcess->deleteLater();
@@ -133,18 +137,27 @@ void ApplicationNotifier::parseUpdateInfo()
         QByteArray updatesString = line.left(eqpos);
         QByteArray securityString = line.right(line.size() - eqpos - 1);
         
-        securityUpdates = securityString.toInt();
-        updates = updatesString.toInt() - securityUpdates;
-    }
-
-    // ';' not found, apt-check broke :("
-    
-    if (QFile::exists("/var/lib/update-notifier/updates-available")) {
-        setSystemUpToDate(false, updates, securityUpdates, securityUpdates > 0 ? AbstractKDEDModule::SecurityUpdate : NormalUpdate);
-    } else {
-        setSystemUpToDate(true);
+        m_securityUpdates = securityString.toInt();
+        m_normalUpdates = updatesString.toInt() - m_securityUpdates;
     }
+    emit foundUpdates();
     
     m_checkingForUpdates = false;
 }
 
+bool ApplicationNotifier::isSystemUpToDate() const
+{
+    return (m_securityUpdates+m_normalUpdates)==0;
+}
+
+uint ApplicationNotifier::securityUpdatesCount()
+{
+    return m_securityUpdates;
+}
+
+uint ApplicationNotifier::updatesCount()
+{
+    return m_normalUpdates;
+}
+
+#include "ApplicationNotifier.moc"
