@@ -21,19 +21,19 @@
 #include "ReviewsBackend.h"
 
 #include <QtCore/QStringBuilder>
+#include <QtCore/QLocale>
 #include <QDebug>
+#include <QJsonDocument>
+#include <QTemporaryFile>
+#include <QStandardPaths>
+#include <QFileInfo>
+#include <QDir>
 
-#include <KGlobal>
 #include <KIO/Job>
-#include <KLocale>
-#include <KStandardDirs>
-#include <KTemporaryFile>
+#include <KLocalizedString>
 #include <KFilterDev>
 
-#include <LibQApt/Backend>
-
-#include <qjson/parser.h>
-#include <qjson/serializer.h>
+#include <QApt/Backend>
 
 #include <QtOAuth/interface.h>
 
@@ -48,7 +48,7 @@
 static QString getCodename(const QString& value)
 {
     QString ret;
-    QFile f("/etc/lsb-release");
+    QFile f("/etc/os-release");
     if(f.open(QIODevice::ReadOnly|QIODevice::Text)) {
         QRegExp rx(QString("%1=(.+)\n").arg(value));
         while(!f.atEnd()) {
@@ -67,6 +67,7 @@ ReviewsBackend::ReviewsBackend(QObject *parent)
         , m_aptBackend(0)
         , m_serverBase(MuonDataSources::rnRSource())
 {
+    m_distId = getCodename("ID");
     m_loginBackend = new UbuntuLoginBackend(this);
     connect(m_loginBackend, SIGNAL(connectionStateChanged()), SIGNAL(loginStateChanged()));
     connect(m_loginBackend, SIGNAL(connectionStateChanged()), SLOT(refreshConsumerKeys()));
@@ -108,16 +109,20 @@ void ReviewsBackend::setAptBackend(QApt::Backend *aptBackend)
 
 void ReviewsBackend::fetchRatings()
 {
-    QString ratingsCache = KStandardDirs::locateLocal("data", "libmuon/ratings.txt");
-    refreshConsumerKeys();
-
-    // First, load our old ratings cache in case we don't have net connectivity
-    loadRatingsFromFile();
-
-    // Try to fetch the latest ratings from the internet
-    KUrl ratingsUrl(m_serverBase, "review-stats/");
-    KIO::FileCopyJob *getJob = KIO::file_copy(ratingsUrl,
-                               ratingsCache, -1,
+    QString ratingsCache = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)+"/libmuon/ratings.txt";
+    QFileInfo file(ratingsCache);
+    QDir::temp().mkpath(file.dir().path());
+    QUrl ratingsUrl(m_serverBase.toString()+"review-stats/");
+    //default to popcon if not using ubuntu
+    if(m_distId.toLower() == QLatin1String("ubuntu")){
+        refreshConsumerKeys();
+        // First, load our old ratings cache in case we don't have net connectivity
+        loadRatingsFromFile();
+        // Try to fetch the latest ratings from the internet
+    } else {
+        ratingsUrl = QUrl("http://popcon.debian.org/all-popcon-results.gz");
+    }
+    KIO::FileCopyJob *getJob = KIO::file_copy(ratingsUrl, QUrl::fromLocalFile(ratingsCache), -1,
                                KIO::Overwrite | KIO::HideProgressInfo);
     connect(getJob, SIGNAL(result(KJob*)), SLOT(ratingsFetched(KJob*)));
 }
@@ -125,6 +130,7 @@ void ReviewsBackend::fetchRatings()
 void ReviewsBackend::ratingsFetched(KJob *job)
 {
     if (job->error()) {
+        qWarning() << "Couldn't fetch the ratings" <<  job->errorString();
         return;
     }
 
@@ -133,28 +139,54 @@ void ReviewsBackend::ratingsFetched(KJob *job)
 
 void ReviewsBackend::loadRatingsFromFile()
 {
-    QString ratingsCache = KStandardDirs::locateLocal("data", "libmuon/ratings.txt");
-    QIODevice* dev = KFilterDev::deviceForFile(ratingsCache, "application/x-gzip");
-
-    QJson::Parser parser;
-    bool ok = false;
-    QVariant ratings = parser.parse(dev, &ok);
-
-    if (!ok) {
-        qDebug() << "error while parsing ratings: " << ratingsCache;
+    QString ratingsCache = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)+"/libmuon/ratings.txt";
+    QScopedPointer<QIODevice> dev(KFilterDev::deviceForFile(ratingsCache, "application/x-gzip"));
+    if (!dev->open(QIODevice::ReadOnly)) {
+        qWarning() << "Couldn't open ratings.txt" << ratingsCache;
         return;
     }
+    if(m_distId.toLower() == QLatin1String("ubuntu")) {
+        QJsonParseError error;
+        QJsonDocument doc = QJsonDocument::fromJson(dev->readAll(), &error);
 
-    qDeleteAll(m_ratings);
-    m_ratings.clear();
-    foreach (const QVariant &data, ratings.toList()) {
-        Rating *rating = new Rating(data.toMap());
-        if (!rating->ratingCount()) {
-            delete rating;
-            continue;
+        if (error.error != QJsonParseError::NoError) {
+            qDebug() << "error while parsing ratings: " << ratingsCache;
+            return;
+        }
+
+        QVariant ratings = doc.toVariant();
+        qDeleteAll(m_ratings);
+        m_ratings.clear();
+        foreach (const QVariant &data, ratings.toList()) {
+            Rating *rating = new Rating(data.toMap());
+            if (!rating->ratingCount()) {
+                delete rating;
+                continue;
+            }
+            rating->setParent(this);
+            m_ratings[rating->packageName()] = rating;
+        }
+    } else {
+        if(dev->open(QIODevice::ReadOnly)) {
+            while(!dev->atEnd()) {
+                QString line(dev->readLine());
+                QStringList lineContent = line.split(" ");
+                if(lineContent.first() != QLatin1String("Package:") || lineContent.isEmpty()) {
+                    continue;
+                }
+                QString pkgName = lineContent.at(1);
+                lineContent.removeFirst();
+                lineContent.removeFirst();
+
+                Rating *rating = new Rating(pkgName,lineContent);
+                if (!rating->ratingCount()) {
+                    delete rating;
+                    continue;
+                }
+                rating->setParent(this);
+                m_ratings[rating->packageName()] = rating;
+            }
         }
-        rating->setParent(this);
-        m_ratings[rating->packageName()] = rating;
     }
     emit ratingsReady();
 }
@@ -199,7 +231,7 @@ void ReviewsBackend::fetchReviews(AbstractResource* res, int page)
     // But that could be because the Ubuntu Software Center (which I used to
     // figure it out) is written in python, so you have to go hunting to where
     // a variable was initially initialized with a primitive to figure out its type.
-    KUrl reviewsUrl(m_serverBase, QLatin1String("reviews/filter/") % lang % '/'
+    QUrl reviewsUrl(m_serverBase.toString() + QLatin1String("/reviews/filter/") % lang % '/'
             % origin % '/' % QLatin1String("any") % '/' % version % '/' % packageName
             % ';' % appName % '/' % QLatin1String("page") % '/' % QString::number(page));
 
@@ -234,17 +266,17 @@ void ReviewsBackend::reviewsFetched(KJob *j)
 {
     KIO::StoredTransferJob* job = qobject_cast<KIO::StoredTransferJob*>(j);
     Application *app = m_jobHash.take(job);
-    if (job->error()) {
+    if (job->error() || !app) {
         return;
     }
 
-    QJson::Parser parser;
-    bool ok = false;
-    QVariant reviews = parser.parse(job->data(), &ok);
+    QJsonParseError error;
+    QJsonDocument doc = QJsonDocument::fromJson(job->data(), &error);
 
-    if (!ok || !app) {
+    if (error.error != QJsonParseError::NoError) {
         return;
     }
+    QVariant reviews = doc.toVariant();
 
     QList<Review *> reviewsList;
     foreach (const QVariant &data, reviews.toList()) {
@@ -262,7 +294,7 @@ QString ReviewsBackend::getLanguage()
     // The reviews API abbreviates all langs past the _ char except these
     fullLangs << "pt_BR" << "zh_CN" << "zh_TW";
 
-    QString language = KGlobal::locale()->language();
+    QString language = QLocale().bcp47Name();
 
     if (fullLangs.contains(language)) {
         return language;
@@ -293,7 +325,13 @@ void ReviewsBackend::submitReview(AbstractResource* application, const QString&
     data["rating"] = rating;
     data["language"] = getLanguage();
     data["origin"] = app->package()->origin();
-    data["distroseries"] = getCodename("DISTRIB_CODENAME");
+
+    QString distroSeries = getCodename("VERSION");
+    if(!distroSeries.isEmpty()){
+        data["distroseries"] = distroSeries.split(" ").last().remove('(').remove(')');
+    }else{
+        data["distroseries"] = getCodename("PRETTY_NAME").split(" ").last();
+    }
     data["arch_tag"] = app->package()->architecture();
     
     postInformation("reviews/", data);
@@ -313,7 +351,7 @@ void ReviewsBackend::flagReview(Review* r, const QString& reason, const QString&
     postInformation(QString("reviews/%1/flags/").arg(r->id()), data);
 }
 
-QByteArray authorization(QOAuth::Interface* oauth, const KUrl& url, AbstractLoginBackend* login)
+QByteArray authorization(QOAuth::Interface* oauth, const QUrl& url, AbstractLoginBackend* login)
 {
     return oauth->createParametersString(url.url(), QOAuth::POST, login->token(), login->tokenSecret(),
                                            QOAuth::HMAC_SHA1, QOAuth::ParamMap(), QOAuth::ParseForHeaderArguments);
@@ -327,10 +365,10 @@ void ReviewsBackend::postInformation(const QString& path, const QVariantMap& dat
         return;
     }
     
-    KUrl url(m_serverBase, path);
+    QUrl url(m_serverBase.toString() +'/'+ path);
     url.setScheme("https");
     
-    KIO::StoredTransferJob* job = KIO::storedHttpPost(QJson::Serializer().serialize(data), url, KIO::Overwrite | KIO::HideProgressInfo);
+    KIO::StoredTransferJob* job = KIO::storedHttpPost(QJsonDocument::fromVariant(data).toJson(), url, KIO::Overwrite | KIO::HideProgressInfo); //TODO port to QJsonDocument
     job->addMetaData("content-type", "Content-Type: application/json" );
     job->addMetaData("customHTTPHeader", "Authorization: " + authorization(m_oauthInterface, url, m_loginBackend));
     connect(job, SIGNAL(result(KJob*)), this, SLOT(informationPosted(KJob*)));
@@ -380,3 +418,18 @@ void ReviewsBackend::logout()
     Q_ASSERT(m_loginBackend->hasCredentials());
     m_loginBackend->logout();
 }
+
+QString ReviewsBackend::errorMessage() const
+{
+    return i18n("No reviews available for Debian.");
+}
+
+bool ReviewsBackend::isReviewable() const
+{
+    QString m_distId = getCodename(QLatin1String("ID"));
+    if(m_distId == QLatin1String("ubuntu")){
+        return true;
+    }
+    return false;
+}
+
