@@ -21,9 +21,10 @@
 #include "ApplicationBackendTest.h"
 #include <QStringList>
 #include <QAction>
+#include <QFile>
 #include <KProtocolManager>
 #include <KActionCollection>
-#include <qtest_kde.h>
+#include <qtest.h>
 
 #include "modeltest.h"
 #include <ApplicationBackend.h>
@@ -36,7 +37,24 @@
 #include <MuonMainWindow.h>
 #include <QAptActions.h>
 
-QTEST_KDEMAIN( ApplicationBackendTest, GUI )
+QTEST_MAIN( ApplicationBackendTest )
+
+QString getCodename(const QString& value)
+{
+    QString ret;
+    QFile f("/etc/os-release");
+    if(f.open(QIODevice::ReadOnly|QIODevice::Text)){
+	QRegExp rx(QString("%1=(.+)\n").arg(value));
+	while(!f.atEnd()) {
+	    QByteArray line = f.readLine();
+	    if(rx.exactMatch(line)) {
+		ret = rx.cap(1);
+		break;
+	    }
+	}
+    }
+    return ret;
+}
 
 AbstractResourcesBackend* backendByName(ResourcesModel* m, const QString& name)
 {
@@ -51,14 +69,36 @@ AbstractResourcesBackend* backendByName(ResourcesModel* m, const QString& name)
 
 ApplicationBackendTest::ApplicationBackendTest()
 {
-    ResourcesModel* m = new ResourcesModel("muon-appsbackend", this);
+    QString ratingsDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)+"/libmuon/ratings.txt";
+    QFile testRatings("~/.kde-unit-test/share/apps/libmuon/ratings.txt");
+    QFile ratings(ratingsDir);
+    QString codeName = getCodename("ID");
+    if(!testRatings.exists()) {
+        if(ratings.exists()) {
+            ratings.copy(testRatings.fileName());
+        } else {
+            ratings.close();
+            if(codeName.toLower() == QLatin1String("ubuntu")) {
+                ratingsDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)+"/libmuon/rnrtestratings.txt";
+            } else {
+                ratingsDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)+"/libmuon/popcontestratings.txt";
+            }
+            ratings.setFileName(ratingsDir);
+            if(ratings.exists()) {
+                ratings.copy(testRatings.fileName());
+            }
+        }
+        testRatings.close();
+        ratings.close();
+    }
+    ResourcesModel* m = new ResourcesModel("muon-applications-backend", this);
     m_window = new MuonMainWindow;
     m->integrateMainWindow(m_window);
     new ModelTest(m,m);
-
     m_appBackend = backendByName(m, "ApplicationBackend");
     QVERIFY(m_appBackend); //TODO: test all backends
-    QTest::kWaitForSignal(m, SIGNAL(allInitialized()));
+    QSignalSpy s(m, SIGNAL(allInitialized()));
+    QVERIFY(s.wait());
 }
 
 ApplicationBackendTest::~ApplicationBackendTest()
@@ -103,14 +143,12 @@ void ApplicationBackendTest::testCategories()
     for(int i=0; i<categoryModel->rowCount(); ++i) {
         Category* cat = categoryModel->categoryForRow(i);
         proxy->setFiltersFromCategory(cat);
-        qDebug() << "fuuuuuu" << proxy->rowCount() << cat->name();
     }
 }
 
 void ApplicationBackendTest::testRefreshUpdates()
 {
     ResourcesModel* m = ResourcesModel::global();
-    AbstractBackendUpdater* updater = m_appBackend->backendUpdater();
 
     QSignalSpy spy(m, SIGNAL(fetchingChanged()));
     QAptActions::self()->actionCollection()->action("update")->trigger();
