@@ -19,15 +19,17 @@
  ***************************************************************************/
 
 #include "DummyResource.h"
+#include <Transaction/AddonList.h>
 #include <krandom.h>
 #include <QDesktopServices>
 #include <QStringList>
 
-DummyResource::DummyResource(const QString& name, AbstractResourcesBackend* parent)
+DummyResource::DummyResource(const QString& name, bool isTechnical, AbstractResourcesBackend* parent)
     : AbstractResource(parent)
     , m_name(name)
     , m_state(State::Broken)
-    , m_addons(QList<PackageState>() << PackageState("a", "aaaaaa", false) << PackageState("b", "aaaaaa", false) << PackageState("c", "aaaaaa", false))
+    , m_addons({ PackageState("a", "aaaaaa", false), PackageState("b", "aaaaaa", false), PackageState("c", "aaaaaa", false)})
+    , m_isTechnical(isTechnical)
 {
     if(KRandom::random() % 2)
         m_screenshot = QUrl("http://www.kde.org/stuff/clipart/klogo-official-oxygen-128x128.png");
@@ -65,7 +67,7 @@ QUrl DummyResource::homepage()
 
 QString DummyResource::icon() const
 {
-    return "kalarm";
+    return isTechnical() ? "kalarm" : "kmail";
 }
 
 QString DummyResource::installedVersion() const
@@ -98,7 +100,7 @@ QString DummyResource::name()
 
 QString DummyResource::origin() const
 {
-    return "dummy";
+    return "DummySource1";
 }
 
 QString DummyResource::packageName() const
@@ -136,6 +138,27 @@ void DummyResource::setState(AbstractResource::State state)
     m_state = state;
     emit stateChanged();
 }
+
+void DummyResource::setAddons(const AddonList& addons)
+{
+    for(const QString& toInstall : addons.addonsToInstall()) {
+        setAddonInstalled(toInstall, true);
+    }
+    for(const QString& toRemove : addons.addonsToRemove()) {
+        setAddonInstalled(toRemove, false);
+    }
+}
+
+void DummyResource::setAddonInstalled(const QString& addon, bool installed)
+{
+    for(QList<PackageState>::iterator it = m_addons.begin(), itEnd = m_addons.end(); it!=itEnd; ++it) {
+        if(it->name() == addon) {
+            it->setInstalled(installed);
+        }
+    }
+}
+
+
 void DummyResource::invokeApplication() const
 {
     QDesktopServices d;
