@@ -23,11 +23,12 @@
 
 #include <resources/AbstractResource.h>
 
+class AddonList;
 class DummyResource : public AbstractResource
 {
 Q_OBJECT
 public:
-    explicit DummyResource(const QString& name, AbstractResourcesBackend* parent);
+    explicit DummyResource(const QString& name, bool isTechnical, AbstractResourcesBackend* parent);
 
     virtual QList<PackageState> addonsInformation();
     virtual QString section();
@@ -46,17 +47,21 @@ public:
     virtual QString comment();
     virtual QString name();
     virtual QString packageName() const;
-    virtual bool isTechnical() const { return false; }
-    void setState(State state);
+    virtual bool isTechnical() const { return m_isTechnical; }
     virtual bool canExecute() const { return true; }
     virtual void invokeApplication() const;
     virtual void fetchChangelog();
+    void setState(State state);
+    void setAddons(const AddonList& addons);
+
+    void setAddonInstalled(const QString& addon, bool installed);
 
 public:
     QString m_name;
     AbstractResource::State m_state;
     QUrl m_screenshot;
     QList<PackageState> m_addons;
+    bool m_isTechnical;
 };
 
 #endif // DUMMYRESOURCE_H
