@@ -23,10 +23,14 @@
 
 #include <QtCore/QObject>
 #include <QUrl>
+#include <QStringList>
+#include <QScopedPointer>
+#include <QCollatorSortKey>
 
 #include "libmuonprivate_export.h"
 #include "PackageState.h"
 
+class Rating;
 class AbstractResourcesBackend;
 
 /**
@@ -62,6 +66,7 @@ class MUONPRIVATE_EXPORT AbstractResource : public QObject
     Q_PROPERTY(QString section READ section CONSTANT)
     Q_PROPERTY(QStringList mimetypes READ mimetypes CONSTANT)
     Q_PROPERTY(AbstractResourcesBackend* backend READ backend CONSTANT)
+    Q_PROPERTY(Rating* rating READ rating NOTIFY ratingFetched)
     public:
         /**
          * This describes the state of the resource
@@ -85,82 +90,99 @@ class MUONPRIVATE_EXPORT AbstractResource : public QObject
             Upgradeable
         };
         Q_ENUMS(State)
-        
+
         /**
          * Constructs the AbstractResource with its corresponding backend
          */
         explicit AbstractResource(AbstractResourcesBackend* parent);
-        
+
         ///used as internal identification of a resource
         virtual QString packageName() const = 0;
-        
+
         ///resource name to be displayed
         virtual QString name() = 0;
-        
+
         ///short description of the resource
         virtual QString comment() = 0;
-        
+
         ///xdg-compatible icon name to represent the resource
         virtual QString icon() const = 0;
-        
+
         ///@returns whether invokeApplication makes something
         /// false if not overridden
         virtual bool canExecute() const;
-        
+
         ///executes the resource, if applies.
         Q_SCRIPTABLE virtual void invokeApplication() const;
-        
+
         virtual State state() = 0;
-        
+
         virtual QStringList categories() = 0;
-        
+
         ///@returns a URL that points to the content
         virtual QUrl homepage() = 0;
-        
+
         virtual bool isTechnical() const;
 
         virtual QUrl thumbnailUrl() = 0;
         virtual QUrl screenshotUrl() = 0;
-        
+
         virtual int downloadSize() = 0;
         virtual QString sizeDescription();
         virtual QString license() = 0;
-        
+
         virtual QString installedVersion() const = 0;
         virtual QString availableVersion() const = 0;
         virtual QString longDescription() = 0;
-        
+
         virtual QString origin() const = 0;
         virtual QString section() = 0;
-        
+
         ///@returns what kind of mime types the resource can consume
         virtual QStringList mimetypes() const;
-        
+
         virtual QList<PackageState> addonsInformation() = 0;
         bool isFromSecureOrigin() const;
-        
+
         virtual QStringList executables() const;
 
         bool canUpgrade();
         bool isInstalled();
-        
+
         ///@returns a user-readable explaination of the resource status
         ///by default, it will specify what state() is returning
         virtual QString status();
 
         AbstractResourcesBackend* backend() const;
 
+        /**
+         * @returns a name sort key for faster sorting 
+         */
+        QCollatorSortKey nameSortKey();
+
+        /**
+         * Convenience method to fetch the resource's rating
+         *
+         * @returns the rating for the resource or null if not available
+         */
+        Rating* rating() const;
+
     public slots:
         virtual void fetchScreenshots();
         virtual void fetchChangelog() = 0;
 
     signals:
         void stateChanged();
-        
+        void ratingFetched();
+
         ///response to the fetchScreenshots method
         ///@p thumbnails and @p screenshots should have the same number of elements
         void screenshotsFetched(const QList<QUrl>& thumbnails, const QList<QUrl>& screenshots);
         void changelogFetched(const QString& changelog);
+
+    private:
+//         TODO: make it std::optional or make QCollatorSortKey()
+        QScopedPointer<QCollatorSortKey> m_collatorKey;
 };
 
 #endif // ABSTRACTRESOURCE_H
