@@ -20,9 +20,6 @@
 
 #include "ResourcesModel.h"
 
-#include <KGlobal>
-#include <KDebug>
-
 #include "AbstractResource.h"
 #include "resources/AbstractResourcesBackend.h"
 #include <ReviewsBackend/Rating.h>
@@ -35,7 +32,7 @@
 #include <QCoreApplication>
 #include <QThread>
 
-static const KCatalogLoader loader("libmuon");
+// static const KCatalogLoader loader("libmuon");//FIXME port
 
 ResourcesModel *ResourcesModel::s_self = nullptr;
 
@@ -60,28 +57,6 @@ void ResourcesModel::init(bool load)
     Q_ASSERT(!s_self);
     Q_ASSERT(QCoreApplication::instance()->thread()==QThread::currentThread());
 
-    QHash< int, QByteArray > roles = roleNames();
-    roles[NameRole] = "name";
-    roles[IconRole] = "icon";
-    roles[CommentRole] = "comment";
-    roles[StateRole] = "state";
-    roles[RatingRole] = "rating";
-    roles[RatingPointsRole] = "ratingPoints";
-    roles[SortableRatingRole] = "sortableRating";
-    roles[ActiveRole] = "active";
-    roles[InstalledRole] = "isInstalled";
-    roles[ApplicationRole] = "application";
-    roles[OriginRole] = "origin";
-    roles[CanUpgrade] = "canUpgrade";
-    roles[PackageNameRole] = "packageName";
-    roles[IsTechnicalRole] = "isTechnical";
-    roles[CategoryRole] = "category";
-    roles[SectionRole] = "section";
-    roles[MimeTypes] = "mimetypes";
-    roles.remove(Qt::EditRole);
-    roles.remove(Qt::WhatsThisRole);
-    setRoleNames(roles);
-
     connect(TransactionModel::global(), SIGNAL(transactionAdded(Transaction*)), SLOT(resourceChangedByTransaction(Transaction*)));
     connect(TransactionModel::global(), SIGNAL(transactionRemoved(Transaction*)), SLOT(resourceChangedByTransaction(Transaction*)));
     if(load)
@@ -104,6 +79,31 @@ ResourcesModel::~ResourcesModel()
     qDeleteAll(m_backends);
 }
 
+QHash<int, QByteArray> ResourcesModel::roleNames() const
+{
+    QHash<int, QByteArray> roles = QAbstractItemModel::roleNames();
+    roles[NameRole] = "name";
+    roles[IconRole] = "icon";
+    roles[CommentRole] = "comment";
+    roles[StateRole] = "state";
+    roles[RatingRole] = "rating";
+    roles[RatingPointsRole] = "ratingPoints";
+    roles[SortableRatingRole] = "sortableRating";
+    roles[ActiveRole] = "active";
+    roles[InstalledRole] = "isInstalled";
+    roles[ApplicationRole] = "application";
+    roles[OriginRole] = "origin";
+    roles[CanUpgrade] = "canUpgrade";
+    roles[PackageNameRole] = "packageName";
+    roles[IsTechnicalRole] = "isTechnical";
+    roles[CategoryRole] = "category";
+    roles[SectionRole] = "section";
+    roles[MimeTypes] = "mimetypes";
+    roles.remove(Qt::EditRole);
+    roles.remove(Qt::WhatsThisRole);
+    return roles;
+}
+
 void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
 {
     Q_ASSERT(!m_backends.contains(backend));
@@ -154,6 +154,7 @@ QModelIndex ResourcesModel::resourceIndex(AbstractResource* res) const
         if(m_backends[i]!=backend)
             row += m_resources[i].size();
         else {
+            Q_ASSERT(!m_backends[i]->isFetching());
             int pos = m_resources[i].indexOf(res);
             Q_ASSERT(pos>=0);
             return index(row+pos);
@@ -178,8 +179,7 @@ QVariant ResourcesModel::data(const QModelIndex& index, int role) const
         case RatingPointsRole:
         case RatingRole:
         case SortableRatingRole: {
-            AbstractReviewsBackend* ratings = resource->backend()->reviewsBackend();
-            Rating* rating = ratings ? ratings->ratingForApplication(resource) : nullptr;
+            Rating* rating = resource->rating();
             return rating ? rating->property(roleNames().value(role)) : -1;
         }
         case Qt::DecorationRole:
@@ -192,7 +192,7 @@ QVariant ResourcesModel::data(const QModelIndex& index, int role) const
             const QMetaObject* m = resource->metaObject();
             int propidx = roleText.isEmpty() ? -1 : m->indexOfProperty(roleText);
 
-            if(KDE_ISUNLIKELY(propidx < 0)) {
+            if(Q_UNLIKELY(propidx < 0)) {
                 qDebug() << "unknown role:" << role << roleText;
                 return QVariant();
             } else
@@ -214,13 +214,13 @@ int ResourcesModel::rowCount(const QModelIndex& parent) const
     return ret;
 }
 
-void ResourcesModel::cleanBackend(AbstractResourcesBackend* backend)
+int ResourcesModel::rowsBeforeBackend(AbstractResourcesBackend* backend, QVector<QVector<AbstractResource*>>::iterator& backendsResources)
 {
-    m_initializingBackends++;
     Q_ASSERT(backend);
     int pos = m_backends.indexOf(backend);
     Q_ASSERT(pos>=0);
-    QVector<AbstractResource*>* backendsResources = &m_resources[pos];
+    backendsResources = m_resources.begin()+pos;
+
     int before = 0;
     for(auto it = m_resources.constBegin();
         it != m_resources.constEnd() && it != backendsResources;
@@ -228,7 +228,16 @@ void ResourcesModel::cleanBackend(AbstractResourcesBackend* backend)
     {
         before+= it->size();
     }
+    return before;
+}
+
+void ResourcesModel::cleanBackend(AbstractResourcesBackend* backend)
+{
+    m_initializingBackends++;
     
+    QVector<QVector<AbstractResource*>>::iterator backendsResources;
+    int before = rowsBeforeBackend(backend, backendsResources);
+
     if (backendsResources->isEmpty()) {
         return;
     }
@@ -254,16 +263,9 @@ void ResourcesModel::resetBackend(AbstractResourcesBackend* backend)
     QVector<AbstractResource*> res = backend->allResources();
 
     if(!res.isEmpty()) {
-        int pos = m_backends.indexOf(backend);
-        Q_ASSERT(pos>=0);
-        QVector<AbstractResource*>* backendsResources = &m_resources[pos];
-        int before = 0;
-        for(auto it=m_resources.constBegin();
-            it != m_resources.constEnd() && it !=backendsResources;
-            ++it)
-        {
-            before += it->size();
-        }
+        QVector<QVector<AbstractResource*>>::iterator backendsResources;
+        int before = rowsBeforeBackend(backend, backendsResources);
+        Q_ASSERT(backendsResources->isEmpty());
         
         beginInsertRows(QModelIndex(), before, before+res.size()-1);
         *backendsResources = res;
@@ -278,15 +280,10 @@ void ResourcesModel::resetBackend(AbstractResourcesBackend* backend)
 void ResourcesModel::updateCaller()
 {
     AbstractResourcesBackend* backend = qobject_cast<AbstractResourcesBackend*>(sender());
-    int pos = m_backends.indexOf(backend);
-    QVector<AbstractResource*>* backendsResources = &m_resources[pos];
-    int before = 0;
-    for(auto it=m_resources.constBegin();
-        it!=m_resources.constEnd() && it!=backendsResources;
-        ++it)
-    {
-        before+= it->size();
-    }
+    QVector<QVector<AbstractResource*>>::iterator backendsResources;
+    int before = rowsBeforeBackend(backend, backendsResources);
+    if (backendsResources->isEmpty())
+        return;
     
     emit dataChanged(index(before), index(before+backendsResources->size()-1));
 }
@@ -354,7 +351,7 @@ void ResourcesModel::registerAllBackends()
     MuonBackendsFactory f;
     QList<AbstractResourcesBackend*> backends = f.allBackends();
     if(m_initializingBackends==0 && backends.isEmpty()) {
-        kWarning() << "Couldn't find any backends";
+        qWarning() << "Couldn't find any backends";
         emit allInitialized();
     } else {
         foreach(AbstractResourcesBackend* b, backends) {
@@ -381,6 +378,7 @@ void ResourcesModel::integrateMainWindow(MuonMainWindow* w)
 
 void ResourcesModel::resourceChangedByTransaction(Transaction* t)
 {
+    Q_ASSERT(!t->resource()->backend()->isFetching());
     QModelIndex idx = resourceIndex(t->resource());
     if(idx.isValid())
         dataChanged(idx, idx);
